@@ -6,14 +6,16 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..13\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Tk ;
 use ExtUtils::testlib;
 use Tk::Multi::Manager;
 use Puppet::Log ;
 $loaded = 1;
-print "ok 1\n";
+my $idx = 1;
+print "ok ",$idx++,"\n";
+my $trace = shift || 0 ;
 
 ######################### End of black magic.
 
@@ -36,43 +38,64 @@ $spe -> Button (text => 'add',
                 command => sub {$toto -> insertText("added\n")} ) 
   -> pack (side => 'left') ;
 
-print "creating manager\n";
+print "creating manager\n" if $trace;
 my $wmgr = $mw -> MultiManager ( 'title' => 'log test' ,
                              'menu' => $w_menu ) -> pack ();
 
-print "Creating new log\n" ;
+print "ok ",$idx++,"\n";
+
+print "Creating new log\n" if $trace ;
 my $log = new Puppet::Log('log test') ;
 
-print "inserting some text in log\n";
-$log -> log("This text was logged but not printed") ;
-$log -> log("This text was logged and printed",'whenNoDisplay' => 'print') ;
-$log -> log("This text was also logged and warned" ,
-            'whenNoDisplay' => 'print') ;
+print "ok ",$idx++,"\n";
 
-print "requiring display on log\n";
+print "inserting some text in log\n" if $trace ;
+$log -> log("This text was logged but not printed") ;
+#$log -> log("This text was logged and printed",'whenNoDisplay' => 'print') ;
+#$log -> log("This text was also logged and warned" ,
+#            'whenNoDisplay' => 'print') ;
+
+print "ok ",$idx++,"\n";
+
+print "requiring display on log\n" if $trace ;
 $log ->display($wmgr, 1) ;
 $log -> log("This text was also logged after display was created" ,
             'whenNoDisplay' => 'print') ;
 
-print "Creating new log2\n" ;
+print "ok ",$idx++,"\n";
+
+print "Creating new log2\n"  if $trace ;
 my $log2 = new Puppet::Log('log2 test') ;
 
-print "inserting some text in log2\n";
+print "ok ",$idx++,"\n";
+
+print "inserting some text in log2\n" if $trace ;
 $log2 -> log("This text was logged but not printed") ;
 
-print "requiring display on log\n";
+print "ok ",$idx++,"\n";
+
+print "requiring display on log\n" if $trace ;
 $log2 ->display($wmgr,1) ;
 $f->command(-label => 'show log2',  -command => sub{$log2->show();} );
 
-print "Creating sub window toto\n";
+print "ok ",$idx++,"\n";
+
+print "Creating sub window toto\n" if $trace ;
 $toto = $wmgr -> newSlave('type'=>'MultiText', title => 'toto') ;
 
-print "Creating orphan log window\n";
+print "ok ",$idx++,"\n";
+
+print "Creating orphan log window\n" if $trace ;
 my $orphan = new Puppet::Log('orphan') ;
 $orphan -> log ("poor guy") ;
+
+print "ok ",$idx++,"\n";
+
 my $orphanb = new Puppet::Log('orphan2') ;
 $orphanb -> log ("poor brother") ;
 
+print "ok ",$idx++,"\n";
+
 $spe -> Button (text => 'recall orphan log', 
                  command => sub {$orphan -> display($mw) ;} ) 
   -> pack (side => 'left');
@@ -83,7 +106,12 @@ $spe -> Button (text => 'recall orphan brother',
 my $bmgr = $orphan -> display($mw) ;
 $orphanb -> display($bmgr) ;
 
-$f->command(-label => 'Quit',  -command => sub{exit;} );
+print "ok ",$idx++,"\n";
+
+$f->command(-label => 'Quit',  -command => sub{$mw->destroy;} );
 
 MainLoop ; # Tk's
 
+print "ok ",$idx++,"\n";
+
+
